/*global define*/
/*jslint browser:true*/
define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!./packstation-test',
    'testsuite/sinon',
    'jquery',
    'de_epages/dhlintraship/ui/packstation',
    'ep/ui/input'
], function (QUnit, fixture, sinon, $, packstation) {

    'use strict';

    QUnit.module("de_epages/dhlintraship/ui/packstation", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest('Show DHLIntraship packstation service results to pick up the package (2 points found)', 6, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var sandbox = sinon.sandbox.create(),
            server = sandbox.useFakeServer();

        server.autoRespond = true;
        server.autoRespondAfter = 400;
        server.respondWith('POST', '', [200, { 'Content-Type': 'application/json' },
            '[' + 
                '{ "address" : "Engelplatz 8", "city" : "Jena", "distance" : "1451", "district" : "West", "latitude" : "50.9261126", "longitude" : "11.5826798", "name" : "Im Eingangsbereich der Postfachanlage", "packstationId" : "103", "zipcode" : "07743" }, ' +
                '{ "address" : "Salvador-Allende-Platz 23", "city" : "Jena", "distance" : "11554", "district" : "Lobeda", "latitude" : "50.8829539", "longitude" : "11.6188628", "name" : "An Seitenwand", "packstationId" : "110", "zipcode" : "07747" }' +
            ']'
        ]);

        $('#DHLIntrashipPackstation')
            .dhlintrashipUiPackstation({
                packstationSelector : $('#DHLIntrashipPackstation'),
                street: 'Heinrich-Heine-Str.',
                streetNo: '1',
                city: 'Jena',
                zipcode: '07749',
                packstationId: '18188'
            });

        setTimeout(function () {

        	var enablePackstationP = $('#EnableDHLIntrashipPackstation').parent();
        	QUnit.ok(!enablePackstationP.hasClass('HideElementSoft'), "Class HideElementSoft has been removed.");

        	QUnit.equal(
                    $('.map_canvas').length,
                    1,
                    'Check if the map item exists'
            );
            
            
            QUnit.ok(
                    $('.map_canvas *').length,
                    'Check if the map item is not empty'
            );
            
            QUnit.equal(
                    $('.locations tr').length,
                    2,
                    '2 rows with packstations in the table'
            );

            QUnit.equal(
                $('.locations tr:eq(0) input[name=location]').val(),
                '103-Im Eingangsbereich der Postfachanlage-Engelplatz 8-07743-Jena',
                'Check value of the first radio element: Im Eingangsbereich der Postfachanlage'
            );

            QUnit.equal(
                $('.locations tr:eq(1) input[name=location]').val(),
                '110-An Seitenwand-Salvador-Allende-Platz 23-07747-Jena',
                'Check value of the second radio element: Salvador-Allende-Platz 23'
            );

            QUnit.start();
        }, 5000);

    });

    QUnit.asyncTest('Show DHLIntraship packstation service results to pick up the package (NO point found)', 2, function () {

        // We have to fake (use sinon.js) the POST request to get data
        var sandbox = sinon.sandbox.create(),
            server = sandbox.useFakeServer();

        server.autoRespond = true;
        server.autoRespondAfter = 400;
        server.respondWith('POST', '', [401, {
            'Content-Type': 'application/json'
        }, ''
        ]);

        $('#DHLIntrashipPackstation')
        .dhlintrashipUiPackstation({
            packstationSelector : $('#DHLIntrashipPackstation'),
            street: 'Heinrich-Heine-Str.',
            streetNo: '1',
            city: 'Jena',
            zipcode: '07749',
            packstationId: '18188'
        });

        setTimeout(function () {

        	var enablePackstationP = $('#EnableDHLIntrashipPackstation').parent();
        	QUnit.ok(enablePackstationP.hasClass('HideElementSoft'), "Class HideElementSoft has not been removed.");

            QUnit.equal(
                $('#DHLPackstation p').length,
                1,
                'Check that there is an error paragraph'
            );
            
            QUnit.start();
        }, 5000);

    });
});