/*global define,ep*/
/*jslint vars:true,nomen:true*/
define("ckeditor/plugins/epcolorbutton/plugin", [
    "jquery",
    "ckeditor/ckeditor",

    "ep/ui/colorpicker"
], function ($, CKEDITOR) {
    'use strict';

    var defaultFontColor = '#000',
        defaultBackgroundColor = '#fff',
        fontColorCommand = 'fontColor',
        backgroundColorCommand = 'backgroundColor';

    var ColorCommand = function (name, style) {
        this.name = name;
        this.style = style;
    };

    ColorCommand.prototype = {
        exec: function (editor) {
            var self = this,
                button = ep('#' + self.uiItems[0]._.id),
                userColors = {},
                key;

            for (key in ep.config.userDefinedColors) {
                if (ep.config.userDefinedColors.hasOwnProperty(key)) {
                    // userColors['UserDefinedColor' + (Number(key) + 1)] = ep.config.userDefinedColors[key];
                    userColors['Color' + Number(key)] = ep.config.userDefinedColors[key];
                }
            }

            button.uiColorpicker({
                autoOpen: true,
                color: self.name === backgroundColorCommand ? defaultBackgroundColor : defaultFontColor,
                orientation: 'bottom',
                transparent: self.name === backgroundColorCommand ? true : false,
                callback: function (color) {
                    editor.fire('saveSnapshot');
                    editor.applyStyle(new CKEDITOR.style(self.style, {
                        color: color
                    }));
                    editor.fire('saveSnapshot');
                },
                extended: {
                    userColors: userColors,
                    userColorsSave: function( data ){
                        var ajaxData = [
                                {name: 'ViewAction',    value: 'JSONViewResponse'},
                                {name: 'ChangeAction',  value: 'SaveGUIDList'},
                                {name: 'ObjectID',      value: ep.config.siteId}
                            ];

                        $.each( data, function(){
                            ajaxData.push(
                                {name: 'GUID',          value: ep.config.defaultStyleId},
                                // {name: 'Name',          value: this.name},
                                {name: 'Name',          value: "UserDefined" + this.name},
                                {name: 'Value',         value: this.value}
                            );
                        });

                        ep.ajax({
                            type:       'post',
                            dataType:   'json',
                            data:       ajaxData
                        });
                    }

                }
            });
        }
    };

    CKEDITOR.plugins.add('epcolorbutton', {
        init: function (editor) {
            var config = editor.config,
                lang = editor.lang.colorbutton;

            // add commands
            editor.addCommand(fontColorCommand, new ColorCommand(fontColorCommand, config.colorButton_foreStyle));
            editor.addCommand(backgroundColorCommand, new ColorCommand(backgroundColorCommand, config.colorButton_backStyle));

            function addButton(name, title, commandName, icon) {
                editor.ui.addButton(name, {
                    label: title,
                    command: commandName,
                    icon: icon
                });
            }

            // add toolbar buttons
            addButton('eptextcolor', lang.textColorTitle, fontColorCommand, this.path + 'images/fontcolor.png');
            addButton('epbgcolor', lang.bgColorTitle, backgroundColorCommand, this.path + 'images/backgroundcolor.png');

            // handle button selection
            editor.on('selectionChange', function (event) {
                var element = editor.getSelection().getStartElement(),
                    hasFontColor = false,
                    hasBackgroundColor = false;

                // return if no element was selected
                if (!element) {
                    return;
                }

                // iterate over the selected element and its parents
                while (element.getName() !== 'body') {
                    var backgroundColor = element.getStyle('background-color'),
                        fontColor = element.getStyle('color');

                    // check if the current element has a font or background color
                    if (fontColor) {
                        hasFontColor = true;
                        defaultFontColor = fontColor;
                    }

                    if (backgroundColor) {
                        hasBackgroundColor = true;
                        defaultBackgroundColor = backgroundColor;
                    }

                    // get next element(parent)
                    element = element.getParent();
                }

                // set state of toolbar buttons
                editor.getCommand(fontColorCommand).setState(hasFontColor ? CKEDITOR.TRISTATE_ON : CKEDITOR.TRISTATE_OFF);
                editor.getCommand(backgroundColorCommand).setState(hasBackgroundColor ? CKEDITOR.TRISTATE_ON : CKEDITOR.TRISTATE_OFF);
            });
        }
    });

    return CKEDITOR;

});