/*globals define, window, CKEDITOR, top, jQuery*/

define([
    'testsuite/qunit',
    'testsuite/qunit-fixture!ep/ui/editor-test',
    'jquery',
    'ep/ui/editor'
], function (QUnit, fixture, $, ep) {

    QUnit.module("ep/ui/editor", {
        setup: fixture.init,
        teardown: fixture.destroy
    });

    QUnit.asyncTest("ep/ui/editor", function () {
        var jq;

        top.jq = jq = $;
        top.jQuery = top.$ = jQuery;

        // editor instance doesn't exist yet
        QUnit.ok(
            CKEDITOR.instances.uieditor_editorID === undefined,
            'editor instance doesn\'t exist yet'
        );

        // create some editors
        var editor = $('#uieditor_editorID').uiEditor({
                name : 'editorName',
                disable: false,
                hideToolbarOnStartup: true,
                toolbar: 'Mini'
            }),
            editor2 = $('#uieditor_editorID02Native').uiEditor({
                name : 'editorName02'
            }),
            editor3 = $('#uieditor_editorID03Translation').uiEditor({
                name : 'editorName02'
            }),
            editor4 = $('#uieditor_editorID04').uiEditor({
                name : 'editorName04'
            });

        // is defined
        QUnit.equal(
            $.isFunction($.ui.uiEditor),
            true,
            "$.isFunction($.ui.uiEditor)"
        );

        // check prototype methods
        $.each(['adjustToolbar', /*'reloadToolbar',*/ 'disableEditor', 'toggleToolbar'], function (i, fn) {

            QUnit.equal(
                $.isFunction($.ui.uiEditor.prototype[fn]),
                true,
                fn + " is a method of ep.ui.Editor"
            );

        });

        // check that editor instance exists now
        QUnit.ok(
            CKEDITOR.instances.uieditor_editorID !== undefined,
            'editor instance exists'
        );

        // check that toolbar of first editor is hidden
        QUnit.ok(
            $('#ep-toolbarContainereditorName').is(':hidden') === true,
            'toolbar of first editor is hidden (option hideToolbarOnStartup is set)'
        );

        setTimeout(function () {
            // get the start width of the toolbar
            var barWidthStart = $('#ep-toolbarContainereditorName02').width();

            // set new width and trigger resize to recalculate the toolbar width
            $('#tableID').width(987);
            $(window).trigger('resize.uiEditor');

            // set focus on first editor -> toolbar becomes visible
            CKEDITOR.instances.uieditor_editorID.focusManager.focus();

            // set last editor visible
            $('#holderId04').show();

            setTimeout(function () {
                // get width of the resized toolbar
                var barWidthResize = $('#ep-toolbarContainereditorName02').width();

                // check if the toolbar width has changed
                QUnit.ok(
                    barWidthResize !== barWidthStart,
                    'resize toolbar'
                );

                // check that toolbar of first editor is visible now
                QUnit.ok(
                    $('#ep-toolbarContainereditorName').is(':hidden') === false,
                    'first editor got focus -> toolbar is shown'
                );

                // check that last editor is visible now
                QUnit.ok(
                    $('#holderId04').is(':visible') === true,
                    'last editor is visible'
                );

                // check that toolbar width has been resized
                QUnit.ok(
                    barWidthResize === $('#ep-toolbarContainereditorName04').width(),
                    'toolbar was resized after getting visible'
                );

                // take focus from first editor -> toolbar becomes invisible
                CKEDITOR.instances.uieditor_editorID.focusManager.blur();

                setTimeout(function () {
                    // check that toolbar of first editor is invisible now
                    QUnit.ok(
                        $('#ep-toolbarContainereditorName').is(':hidden') === true,
                        'first editor lost focus -> toolbar is hidden'
                    );

                    // check destroy method of widget
                    $('#uieditor_editorID04').uiEditor('destroy');

                    QUnit.ok(
                        CKEDITOR.instances.uieditor_editorID04 === undefined,
                        'last editor was destroyed'
                    );

                    // start tests
                    QUnit.start();

                }, 500);

            }, 500);

        }, 500);

    });
});